Files
odoo_source/addons/product
Sébastien Theys 344614b54a [IMP] base, product: optimize image compute when image is not set
All of those fields `__get__` and method calls have a cost, it is small but when
done for many records it adds up, so they are better not done.

When creating 1000 products without image, this compute takes:

47ms +/- 1ms before the commit
37ms +/- 1ms after the commit

That's around 20% less.

Part of task-1918881

closes odoo/odoo#34294

Signed-off-by: Jérémy Kersten (jke) <jke@openerp.com>
2019-06-21 11:09:50 +00:00
..
2018-11-23 15:28:32 +00:00